==> aliyun-python-sdk-sas-2.0.1.tar.gz: aliyun-python-sdk-sas-2.0.1/aliyunsdksas/request/v20181203/ModifyInterceptionTargetRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class ModifyInterceptionTargetRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyInterceptionTarget')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_TargetId(self): # Long
		return self.get_query_params().get('TargetId')

	def set_TargetId(self, TargetId):  # Long
		self.add_query_param('TargetId', TargetId)
	def get_TargetType(self): # String
		return self.get_query_params().get('TargetType')

	def set_TargetType(self, TargetType):  # String
		self.add_query_param('TargetType', TargetType)
	def get_ImageLists(self): # RepeatList
		return self.get_query_params().get('ImageList')

	def set_ImageLists(self, ImageList):  # RepeatList
		for depth1 in range(len(ImageList)):
			self.add_query_param('ImageList.' + str(depth1 + 1), ImageList[depth1])
	def get_TagLists(self): # RepeatList
		return self.get_query_params().get('TagList')

	def set_TagLists(self, TagList):  # RepeatList
		for depth1 in range(len(TagList)):
			self.add_query_param('TagList.' + str(depth1 + 1), TagList[depth1])
	def get_TargetName(self): # String
		return self.get_query_params().get('TargetName')

	def set_TargetName(self, TargetName):  # String
		self.add_query_param('TargetName', TargetName)
	def get_AppName(self): # String
		return self.get_query_params().get('AppName')

	def set_AppName(self, AppName):  # String
		self.add_query_param('AppName', AppName)
	def get_Namespace(self): # String
		return self.get_query_params().get('Namespace')

	def set_Namespace(self, Namespace):  # String
		self.add_query_param('Namespace', Namespace)

==> aliyun-python-sdk-sas-2.0.3.tar.gz: aliyun-python-sdk-sas-2.0.3/aliyunsdksas/request/v20181203/ModifyInterceptionTargetRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class ModifyInterceptionTargetRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'ModifyInterceptionTarget','sas')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_TargetId(self): # Long
		return self.get_query_params().get('TargetId')

	def set_TargetId(self, TargetId):  # Long
		self.add_query_param('TargetId', TargetId)
	def get_TargetType(self): # String
		return self.get_query_params().get('TargetType')

	def set_TargetType(self, TargetType):  # String
		self.add_query_param('TargetType', TargetType)
	def get_ImageLists(self): # RepeatList
		return self.get_query_params().get('ImageList')

	def set_ImageLists(self, ImageList):  # RepeatList
		for depth1 in range(len(ImageList)):
			self.add_query_param('ImageList.' + str(depth1 + 1), ImageList[depth1])
	def get_TagLists(self): # RepeatList
		return self.get_query_params().get('TagList')

	def set_TagLists(self, TagList):  # RepeatList
		for depth1 in range(len(TagList)):
			self.add_query_param('TagList.' + str(depth1 + 1), TagList[depth1])
	def get_TargetName(self): # String
		return self.get_query_params().get('TargetName')

	def set_TargetName(self, TargetName):  # String
		self.add_query_param('TargetName', TargetName)
	def get_AppName(self): # String
		return self.get_query_params().get('AppName')

	def set_AppName(self, AppName):  # String
		self.add_query_param('AppName', AppName)
	def get_Namespace(self): # String
		return self.get_query_params().get('Namespace')

	def set_Namespace(self, Namespace):  # String
		self.add_query_param('Namespace', Namespace)
